/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

/**
 *
 * @author Sandra Escandor
 * Uses results from ProcessingDigitized
 */
public class DecisionMaking {

    //Special Coefficients
    private final double alpha = 0.18; //specified in article
    private final double beta = 0.14; //specified in article
    private final double samplingPeriod = 0.005;
    private final double t1 = 0.006; //specified in article
    private final int NextPosSpacing = 12; //This is how many elements we want to traverse in order to span t1 in the data samples
                                           //that is, in order to get the sample 60ms relative to a sample, we traverse t1/samplingPeriod elements
    
    //Data from ProcessingDigitized
    private double[] differentiation;
    
    //The previous first positive location found by StartLocPosSlope()
    //We want to initialize this value at -5 in the beginning since
    //We want StartLocPosSlope() to start at the zero element of differentiation,
    //and then on subsequent calls, StartLocPosSlope() can start five elements from
    //the previous positive start location in order to find another start location
    private int PrevPosLocFound = -5; 
    
    private int PrevNegLocFound = -5;
    
    private int[] SpTimeIndex;
    
    //Positive Slope detection value that is compared with the threshold positive slope value, THVp
    private double[] Sp;
    //Negative Slope detection value that is compared with the threshold negative slope value, THVn
    private double[] Sn;
    
    //Threshold of positive slope for each peak number
    private double THVp;
    //Threshold of negative slope for each peak number
    private double THVn;
         
    /*
    public boolean PositiveSlopeDetection(int newStartLocation)
    {
        boolean detection = false;
        int p = Sp.length;
        
        //Check for five consecutive slope values from Differentiation data elements
        int newLocation = StartLocSlope(newStartLocation,true);
        
        if(newLocation != PrevPosLocFound)
        {
            //Let's keep track of the location indices of the positive slopes
            SpTimeIndex[p] = newLocation;
            
            //Calculate Sp
            for(int i = PrevPosLocFound; i < (PrevPosLocFound + 5); i++)
            {
                Sp[p] += this.differentiation[i];
            }

            Sp[p] = Sp[p]*0.2; //divide by 5 according to article
                        
            detection = true;
        }
                       
        return detection;
        
    }
    */
    
    public boolean PositiveSlopeDetection(int newStartLocation)
    {
        boolean detection = false;
        
        //Check for five consecutive slope values from Differentiation data elements
        int newLocation = StartLocSlope(newStartLocation,true);
        
        if(newLocation != PrevPosLocFound)
        {
             detection = true;    
        }
                
        return detection;
    }
    
    public void DecisionMaking(double[] differentiation)
    {
        this.differentiation = differentiation;
        InitDecisionMaking();
        
    }//
    
    private void InitDecisionMaking()
    {
        int newNegLocation = 0;
        boolean FoundPosPeak = false;
        int newPosLocation = PrevPosLocFound;         
        
        //To start off, we need to find the first five Sp and the first five Sn.
        //It is only when we have the first five of these two sets, that we are able
        //to calculate the thresholds THVp and THVn.
        
        for(int i = 0; i < 5; i++)
        {
            //Find a concave down (positive slope->max point-> negative slope) region of the curve 
            while(PositiveSlopeDetection(newPosLocation) && FoundPosPeak == false)
            {        
                //We need to ensure that the slope becomes negative
                //within 60ms (as noted in the article) or else
                //we'll have to find a new positive slope starting location
                //Check for five consecutive slope values from Differentiation data elements

                newNegLocation = StartLocSlope(PrevPosLocFound,false);
                
                if(newNegLocation*samplingPeriod < t1)
                {   //This means that the slope became negative within 60ms
                    FoundPosPeak = true;
                }
                else //otherwise, a new positive slope will need to be used.
                {                
                    //We'll need to traverse to the data element in differentiation
                    //that corresponds to sampling 60ms from the previous positive 
                    //location found. In other words, we want to start our new search
                    //for a new positive slope at the data point that is 60ms after the 
                    //previous positive location that was found.
                    newPosLocation = PrevPosLocFound + NextPosSpacing;
                }//else
                                
            }//while
            
            //We've found a concave down region, let's record the values in 
            //Sp and Sn respectively
            
            Sp[i] = this.differentiation[newPosLocation];
            Sn[i] = this.differentiation[newNegLocation];
            
        }//for
        
        //Now that we've found a set of five Sp and Sn, let's calculate the 
        //initial THVp and THVn, respectively
        double sumSp = 0;
        double sumSn = 0;
        for(int i = 0; i<5; i++)
        {
            sumSp += Sp[i];
            sumSn += Sn[i];
        }//for
        
        THVp = (alpha*0.2)*sumSp;
        THVn = (beta*0.2)*sumSn;
                
    }//
    
    public int StartLocSlope(int startLoc, boolean positive)
    {
                
        //We want to return the starting location in the array of Differentiation
        //the starting location where there are five consecutive positive (or negative) values (depending on usage of method)
        //Note: if the returned value is -5, we know that there were not any 
        //five consecutive positive slopes found
        int N = differentiation.length;
        int cnt = 0;
        int location = 0;
                
        int i = startLoc;
        
        while(cnt < 5 && i < N)
        {
            if(positive == true) //We're using this as a positive slope finder
            {
                while(differentiation[i] > 0 && cnt < 5)
                {
                    cnt++;
                    i++;
                }//while
            }
            else //We're using this as a negative slope finder
            {
                while(differentiation[i] < 0 && cnt < 5)
                {
                    cnt++;
                    i++;
                }//while
            }//else
            
            if(cnt < 5) 
            {
                //This means that there was an out of place value encountered
                //Let's move to the next element in differentiation
                i++;
                cnt = 0;
            }//if
        }//while
        
        if(cnt == 5)
            location = i-5;
        else
            location = startLoc;
        
        return location;
        
    }//
    
}//**END**//
