import javax.microedition.lcdui.*;
import javax.microedition.midlet.*;

/*
 * QRSDetection:
 * Implementation of the algorithm created by Adnane,Jiang, and Choi.
 * (Description can be found in: "Development of QRS detection algorithm for 
 * wearable cardiorespiratory system")
 * Article can be found here:
 * http://www.sciencedirect.com/science?_ob=ArticleURL&_udi=B6T5J-4TDJG59-2&_user=1067350&_coverDate=01%2F31%2F2009&_rdoc=1&_fmt=full&_orig=search&_cdi=5004&_sort=d&_docanchor=&view=c&_searchStrId=1175836388&_rerunOrigin=google&_acct=C000051241&_version=1&_urlVersion=0&_userid=1067350&md5=74ca5fd4b5a02dec4ff2415332b306d6#fig4
 * 
 * 
 * Some notes on the incoming data:
 * A) The analog value is converted in the 10-bit ADC of the bluetooth transmitter. 
 * The 10-bit ADC has a voltage reference of 5V. This means that 
 * the LSB = 5mV. In order to translate it back into meaningful data, we need to
 * remember that because each bit value is equivalent to 5mV, then, for 
 * example, if the digital output = 13 (in decimal), then we would know that the actual 
 * voltage coming from the ECG is 13*5mV = 65mV
 * 
 * B) digitized[n] represents the array of values that have been sampled. 
 * This means that n represents the discretization of the analog signal, so that 
 * we can calculate timepoint sampled = nT (where T is the sampling period). So, 
 * if, for example, n = 3, and T = 1/200 s, then we know that the sampled value 
 * at n = 3 corresponds to 3/200 s on the time axis of the sampled signal graph 
 * (the graph being signal amplitude vs. time).
 * 
 */
public class QRSDetection
    extends MIDlet 
    implements CommandListener {
  private Form mMainForm;
  
  public QRSDetection() {
    mMainForm = new Form("Trivariate Normal Analysis");
    mMainForm.append(new StringItem(null, "Trivariate Normal Analysis Started..."));
    mMainForm.addCommand(new Command("Exit", Command.EXIT, 0));
    mMainForm.setCommandListener(this);
  }
  
  
  
  public void startApp() {
    Display.getDisplay(this).setCurrent(mMainForm);
    //ProcessingDigitized process = new ProcessingDigitized();
    
    //double[] digitized = {1,2,4,5,3};
    
    //process.ProcessingDigitized(digitized);
    
    //double[] normalized = process.GetNormalizationResult();
    
    
    //Below is the test code for the statistical analysis
    try{
        
        
        //Enter test sample observation data and test points here (from Matlab code output: CreateAndTestSampleData.m):  
double[][] digitized = {{85.38, 37.42, 120.09},{98.34, 36.56, 119.49},{57.41, 37.05, 120.47},{88.62, 36.73, 120.15},{83.19, 37.15, 120.07},{66.92, 36.70, 120.26},{75.66, 37.24, 120.13},{83.43, 37.37, 119.53},{115.78, 37.86, 119.92},{107.69, 36.90, 119.93},{66.50, 35.93, 119.73},{110.35, 36.58, 120.84},{87.25, 37.68, 119.56},{79.37, 36.46, 119.76},{87.15, 37.48, 119.64},{77.95, 37.06, 119.41},{78.76, 37.72, 119.90},{94.90, 36.02, 119.86},{94.09, 36.90, 120.77},{94.17, 36.40, 119.88},{86.71, 38.45, 119.47},{67.93, 37.41, 120.80},{87.17, 37.69, 120.62},{96.30, 36.47, 119.89},{84.89, 36.77, 119.25},{90.35, 36.86, 119.78},{87.27, 37.55, 119.92},{76.97, 36.86, 120.14},{82.94, 37.35, 119.87},{72.13, 35.97, 120.22},{88.88, 36.82, 120.20},{68.53, 36.59, 119.37},{69.31, 36.21, 119.53},{71.91, 37.25, 119.63},{50.56, 37.14, 119.75},{94.38, 37.02, 119.84},{83.25, 36.33, 120.01},{72.45, 37.56, 118.49},{93.70, 37.18, 119.77},{62.88, 36.85, 120.62},{78.98, 37.01, 119.47},{77.59, 36.87, 120.47},{83.19, 36.12, 120.18},{83.13, 36.86, 119.99},{71.35, 36.58, 120.09},{79.70, 36.51, 119.22},{78.35, 36.42, 119.96},{86.28, 36.73, 120.80},{90.93, 36.00, 120.05},{91.09, 37.48, 120.02},{71.36, 37.26, 119.63},{80.77, 36.99, 119.98},{67.86, 36.98, 120.12},{68.86, 36.60, 120.21},{79.93, 37.51, 119.81},{95.33, 36.93, 119.88},{72.30, 36.64, 121.01},{83.71, 37.68, 118.87},{77.74, 36.89, 121.11},{91.17, 36.71, 120.17},{69.11, 36.85, 120.50},{80.33, 36.58, 119.17},{85.53, 36.44, 119.70},{91.01, 38.26, 119.86},{95.44, 37.83, 120.21},{80.86, 37.15, 119.16},{65.08, 36.37, 120.24},{72.58, 36.57, 119.39},{69.38, 36.91, 120.03},{103.50, 37.40, 120.33},{73.84, 36.33, 120.16},{87.48, 35.84, 120.54},{78.08, 36.28, 120.50},{88.89, 37.17, 119.67},{72.35, 37.20, 120.13},{65.98, 37.23, 119.53},{65.78, 36.93, 119.34},{84.88, 37.09, 120.46},{78.23, 36.76, 120.00},{78.04, 37.43, 119.97},{94.19, 36.32, 120.46},{82.92, 37.23, 120.30},{81.98, 36.58, 120.18},{95.88, 36.83, 120.63},{71.96, 37.28, 120.46},{86.97, 37.52, 120.12},{88.35, 36.44, 119.65},{77.56, 37.63, 119.67},{82.16, 37.33, 120.60},{68.34, 36.97, 119.19},{68.52, 36.90, 119.99},{81.05, 36.89, 119.03},{87.22, 36.85, 120.51},{105.85, 37.01, 120.43},{73.33, 37.03, 120.00},{81.87, 37.41, 119.96},{79.18, 37.76, 118.76},{60.67, 37.23, 120.29},{75.61, 36.90, 118.90},{62.05, 37.31, 118.84}};
double[] point1 = { 81.24, 36.05, 119.06 }; //Outlier Data Test Point 
double[] point2 = { 85.38, 37.42, 120.09 }; //Regular Data Test Point 
double[] point3 = { 51.91, 36.87, 119.78 }; //Warning Data Test Point

        //If you'd like to print out the digitized sample data:
        //Helpers helper = new Helpers(mMainForm); 
        //helper.PrintSampleData(digitized, digitized.length, digitized[0].length);
        
        mMainForm.append(new StringItem(null, "Starting test point classification: \n"));
        
        //Testing MultivariateNormalAnalysis
        trivar_normal multivaranalysis = new trivar_normal(digitized, digitized.length,digitized[0].length);
                                              
        multivaranalysis.setDataMatrix(point1);
    
        double[] point = point1;
        switch(multivaranalysis.FunctionalResult())
        {
            
            
            case 1: 
                mMainForm.append(new StringItem(null, Double.toString(point[0]) + "," + Double.toString(point[1])+ "," + Double.toString(point[2]) + " is a regular point."));
                break;
            case 2:
                mMainForm.append(new StringItem(null, Double.toString(point[0]) + "," + Double.toString(point[1]) + "," + Double.toString(point1[2]) + " is a warning point."));
                double[] offset = multivaranalysis.CheckVitalSignsOffset();
                mMainForm.append(new StringItem(null, "Heart rate is out of chosen observation range by: " + Double.toString(offset[0]*1.00)));
                mMainForm.append(new StringItem(null, "Temperature is out of chosen observation range by: " + Double.toString(offset[1])));
                mMainForm.append(new StringItem(null, "Systolic blood pressure is out of chosen observation range by: " + Double.toString(offset[2])));
                break;
            case 3:
                mMainForm.append(new StringItem(null, Double.toString(point[0]) + "," + Double.toString(point[1]) + "," + Double.toString(point1[2]) + " is a danger point."));
                offset = multivaranalysis.CheckVitalSignsOffset();
                mMainForm.append(new StringItem(null, "Heart rate is out of chosen observation range by: " + Double.toString(offset[0]*1.0)));
                mMainForm.append(new StringItem(null, "Temperature is out of chosen observation range by: " + Double.toString(offset[1])));
                mMainForm.append(new StringItem(null, "Systolic blood pressure is out of chosen observation range by: " + Double.toString(offset[2])));
                
                break;
        }
        
        
        
        multivaranalysis.setDataMatrix(point2);
        
        point = point2;
        switch(multivaranalysis.FunctionalResult())
        {
            case 1: 
                mMainForm.append(new StringItem(null, Double.toString(point[0]) + "," + Double.toString(point[1])+ "," + Double.toString(point[2]) + " is a regular point."));
                break;
            case 2:
                mMainForm.append(new StringItem(null, Double.toString(point[0]) + "," + Double.toString(point[1]) + "," + Double.toString(point[2]) + " is a warning point."));
                double[] offset = multivaranalysis.CheckVitalSignsOffset();
                mMainForm.append(new StringItem(null, "Heart rate is out of chosen observation range by: " + Double.toString(offset[0])));
                mMainForm.append(new StringItem(null, "Temperature is out of chosen observation range by: " + Double.toString(offset[1])));
                mMainForm.append(new StringItem(null, "Systolic blood pressure is out of chosen observation range by: " + Double.toString(offset[2])));
                
                break;
            case 3:
                mMainForm.append(new StringItem(null, Double.toString(point[0]) + "," + Double.toString(point[1]) + "," + Double.toString(point[2]) + " is a danger point."));
                offset = multivaranalysis.CheckVitalSignsOffset();
                mMainForm.append(new StringItem(null, "Heart rate is out of chosen observation range by: " + Double.toString(offset[0])));
                mMainForm.append(new StringItem(null, "Temperature is out of chosen observation range by: " + Double.toString(offset[1])));
                mMainForm.append(new StringItem(null, "Systolic blood pressure is out of chosen observation range by: " + Double.toString(offset[2])));
                
                break;
        }
        
        multivaranalysis.setDataMatrix(point3);
        point = point3;
        switch(multivaranalysis.FunctionalResult())
        {
            case 1: 
                mMainForm.append(new StringItem(null, Double.toString(point[0]) + "," + Double.toString(point[1])+ "," + Double.toString(point[2]) + " is a regular point."));
                break;
            case 2:
                mMainForm.append(new StringItem(null, Double.toString(point[0]) + "," + Double.toString(point[1]) + "," + Double.toString(point[2]) + " is a warning point."));
                double[] offset = multivaranalysis.CheckVitalSignsOffset();
                
                mMainForm.append(new StringItem(null, "Heart rate is out of chosen observation range by: " + Double.toString(offset[0]*1.0)));
                mMainForm.append(new StringItem(null, "Temperature is out of chosen observation range by: " + Double.toString(offset[1])));
                mMainForm.append(new StringItem(null, "Systolic blood pressure is out of chosen observation range by: " + Double.toString(offset[2])));
                
                break;
            case 3: 
                mMainForm.append(new StringItem(null, Double.toString(point[0]) + "," + Double.toString(point[1]) + "," + Double.toString(point[2]) + " is a danger point."));
                offset = multivaranalysis.CheckVitalSignsOffset();
                
                mMainForm.append(new StringItem(null, "Heart rate is out of chosen observation range by: " + Double.toString(offset[0])));
                mMainForm.append(new StringItem(null, "Temperature is out of chosen observation range by: " + Double.toString(offset[1])));
                mMainForm.append(new StringItem(null, "Systolic blood pressure is out of chosen observation range by: " + Double.toString(offset[2])));
                
                break;
        }
        

        
        //This double[] ECGdigitized line is for testing purposes only!
        //We would want to get the ECGdigitized information from the initializer of ProcessingDigitized object.
        double[] ECGdigitized = {-0.168,-0.158,-0.138,-0.140,-0.142,-0.160,-0.172,-0.165,-0.145,-0.138,-0.128,-0.130,-0.133,-0.145,-0.150,-0.165,-0.153,-0.140,-0.115,-0.113,-0.123,-0.130,-0.140,-0.145,-0.140,-0.135,-0.128,-0.123,-0.120,-0.117,-0.147,-0.155,-0.138,-0.142,-0.145,-0.130,-0.115,-0.125,-0.133,-0.147,-0.155,-0.155,-0.142,-0.140,-0.130,-0.142,-0.153,-0.160,-0.170,-0.170,-0.172,-0.158,-0.153,-0.147,-0.175,-0.177,-0.190,-0.195,-0.193,-0.188,-0.185,-0.193,-0.195,-0.212,-0.218,-0.225,-0.228,-0.223,-0.205,-0.193,-0.195,-0.228,-0.223,-0.233,-0.228,-0.218,-0.203,-0.205,-0.198,-0.205,-0.203,-0.205,-0.210,-0.203,-0.193,-0.188,-0.185,-0.188,-0.188,-0.203,-0.203,-0.193,-0.190,-0.185,-0.168,-0.170,-0.188,-0.188,-0.183,-0.190,-0.168,-0.153,-0.150,-0.150,-0.163,-0.165,-0.172,-0.170,-0.177,-0.163,-0.153,-0.147,-0.155,-0.165,-0.175,-0.180,-0.168,-0.123,-0.108,-0.072,-0.037,0.005,0.070,0.117,0.153,0.165,0.123,0.043,-0.060,-0.207,-0.333,-0.427,-0.515,-0.555,-0.593,-0.610,-0.615,-0.595,-0.568,-0.525,-0.490,-0.445,-0.415,-0.380,-0.352,-0.343,-0.318,-0.295,-0.278,-0.253,-0.237,-0.218,-0.200,-0.195,-0.190,-0.203,-0.223,-0.210,-0.195,-0.200,-0.180,-0.172,-0.180,-0.188,-0.195,-0.210,-0.195,-0.185,-0.175,-0.172,-0.165,-0.170,-0.177,-0.180,-0.175,-0.172,-0.160,-0.160,-0.150,-0.153,-0.158,-0.168,-0.158,-0.158,-0.145,-0.125,-0.117,-0.120,-0.130,-0.133,-0.130,-0.113,-0.090,-0.065,-0.052,-0.052,-0.030,-0.028,-0.013,-0.003,0.013,0.030,0.043,0.043,0.048,0.040,0.055,0.070,0.083,0.117,0.135,0.150,0.145,0.145,0.153,0.153,0.158,0.175,0.195,0.200,0.190,0.163,0.153,0.135,0.125,0.117,0.117,0.117,0.092,0.068,0.033,0.003,-0.010,-0.025,-0.020,-0.015,-0.022,-0.037,-0.050,-0.077,-0.085,-0.100,-0.090,-0.087,-0.087,-0.090,-0.102,-0.117,-0.128,-0.130,-0.115,-0.120,-0.115,-0.117,-0.115,-0.123,-0.135,-0.140,-0.138,-0.130,-0.120,-0.130,-0.135,-0.140,-0.155,-0.145,-0.155,-0.138,-0.138,-0.128,-0.133,-0.145,-0.165,-0.155,-0.153,-0.142,-0.140,-0.142,-0.133,-0.142,-0.158,-0.158,-0.160,-0.150,-0.135,-0.125,-0.123,-0.128,-0.147,-0.150,-0.155,-0.147,-0.142,-0.135,-0.125,-0.133,-0.130,-0.145,-0.155,-0.147,-0.140,-0.130,-0.130,-0.135,-0.138,-0.155,-0.170,-0.165,-0.170,-0.158,-0.147,-0.145,-0.153,-0.153,-0.142,-0.155,-0.147,-0.142,-0.138,-0.130,-0.128,-0.135,-0.138,-0.160,-0.160,-0.142,-0.140,-0.125,-0.133,-0.145,-0.142,-0.160,-0.153,-0.153,-0.133,-0.130,-0.125,-0.135,-0.135,-0.153,-0.147,-0.153,-0.153,-0.138,-0.130,-0.125,-0.142,-0.153,-0.163,-0.153,-0.147,-0.142,-0.138,-0.135,-0.145,-0.150,-0.165,-0.170,-0.158,-0.160,-0.140,-0.135,-0.135,-0.147,-0.142,-0.153,-0.155,-0.133,-0.130,-0.130,-0.135,-0.145,-0.150,-0.158,-0.153,-0.158,-0.150,-0.135,-0.135,-0.147,-0.153,-0.163,-0.160,-0.160,-0.155,-0.142,-0.140,-0.140,-0.128,-0.147,-0.153,-0.138,-0.135,-0.108,-0.108,-0.113,-0.110,-0.125,-0.135,-0.142,-0.138,-0.120,-0.108,-0.105,-0.117,-0.120,-0.133,-0.142,-0.130,-0.123,-0.113,-0.120,-0.115,-0.135,-0.150,-0.138,-0.138,-0.135,-0.117,-0.123,-0.130,-0.135,-0.140,-0.135,-0.147,-0.142,-0.133,-0.115,-0.123,-0.130,-0.153,-0.155,-0.170,-0.158,-0.145,-0.138,-0.130,-0.125,-0.128,-0.133,-0.135,-0.135,-0.125,-0.117,-0.102,-0.102,-0.113,-0.125,-0.135,-0.123,-0.128,-0.117,-0.120,-0.100,-0.113,-0.123,-0.135,-0.140,-0.142,-0.123,-0.117,-0.113,-0.120,-0.117,-0.133,-0.138,-0.135,-0.128,-0.120,-0.113,-0.117,-0.123,-0.125,-0.153,-0.142,-0.123,-0.120,-0.123,-0.120,-0.133,-0.147,-0.153,-0.160,-0.155,-0.123,-0.108,-0.102,-0.110,-0.117,-0.138,-0.142,-0.130,-0.123,-0.100,-0.098,-0.108,-0.105,-0.120,-0.138,-0.117,-0.100,-0.068,-0.025,0.035,0.100,0.160,0.198,0.223,0.223,0.175,0.130,0.052,-0.040,-0.138,-0.240,-0.315,-0.380,-0.430,-0.443,-0.430,-0.415,-0.385,-0.373,-0.367,-0.347,-0.325,-0.313,-0.287,-0.265,-0.250,-0.240,-0.230,-0.212,-0.203,-0.190,-0.185,-0.185,-0.180,-0.183,-0.198,-0.193,-0.195,-0.188,-0.170,-0.168,-0.175,-0.168,-0.185,-0.188,-0.185,-0.177,-0.158,-0.150,-0.145,-0.147,-0.155,-0.168,-0.163,-0.165,-0.160,-0.142,-0.135,-0.138,-0.140,-0.145,-0.153,-0.142,-0.128,-0.108,-0.090,-0.095,-0.092,-0.108,-0.100,-0.105,-0.090,-0.063,-0.045,-0.037,-0.035,-0.025,-0.020,-0.010,0.010,0.018,0.037,0.055,0.070,0.060,0.065,0.070,0.095,0.108,0.138,0.153,0.168,0.160,0.158,0.163,0.165,0.170,0.177,0.193,0.195,0.185,0.165,0.153,0.142,0.123,0.120,0.110,0.098,0.090,0.068,0.040,0.018,0.000,-0.003,0.000,-0.003,-0.022,-0.048,-0.058,-0.072,-0.075,-0.072,-0.065,-0.050,-0.063,-0.058,-0.077,-0.080,-0.083,-0.087,-0.077,-0.065,-0.058,-0.065,-0.063,-0.080,-0.095,-0.095,-0.085,-0.072,-0.063,-0.075,-0.085,-0.105,-0.113,-0.110,-0.113,-0.095,-0.072,-0.083,-0.083,-0.108,-0.105,-0.115,-0.102,-0.095,-0.092,-0.085,-0.080,-0.092,-0.108,-0.105,-0.102,-0.105,-0.090,-0.077,-0.100,-0.098,-0.123,-0.120,-0.110,-0.110,-0.113,-0.098,-0.092,-0.092,-0.105,-0.115,-0.130,-0.113,-0.090,-0.083,-0.098,-0.092,-0.100,-0.123,-0.115,-0.120,-0.113,-0.100,-0.102,-0.108,-0.123,-0.125,-0.135,-0.125,-0.110,-0.095,-0.102,-0.098,-0.095,-0.098,-0.117,-0.117,-0.110,-0.100,-0.090,-0.083,-0.080,-0.092,-0.110,-0.105,-0.120,-0.105,-0.092,-0.083,-0.087,-0.095,-0.110,-0.117,-0.120,-0.102,-0.095,-0.090,-0.087,-0.098,-0.108,-0.117,-0.115,-0.105,-0.095,-0.090,-0.072,-0.087,-0.095,-0.110,-0.115,-0.117,-0.102,-0.085,-0.072,-0.072,-0.092,-0.098,-0.100,-0.098,-0.095,-0.070,-0.070,-0.068,-0.072,-0.080,-0.098,-0.105,-0.100,-0.087,-0.087,-0.077,-0.080,-0.090,-0.105,-0.110,-0.102,-0.095,-0.087,-0.077,-0.077,-0.090,-0.095,-0.092,-0.090,-0.090,-0.083,-0.070,-0.070,-0.080,-0.090,-0.098,-0.098,-0.092,-0.080,-0.070,-0.072,-0.075,-0.085,-0.092,-0.098,-0.087,-0.083,-0.068,-0.068,-0.068,-0.080,-0.087,-0.102,-0.085,-0.085,-0.072,-0.083,-0.070,-0.065,-0.080,-0.090,-0.085,-0.092,-0.075,-0.072,-0.060,-0.063,-0.083,-0.083,-0.087,-0.087,-0.080,-0.068,-0.060,-0.065,-0.080,-0.092,-0.092,-0.087,-0.087,-0.068,-0.065,-0.052,-0.055,-0.075,-0.077,-0.080,-0.087,-0.072,-0.063,-0.060,-0.060,-0.075,-0.090,-0.092,-0.090,-0.077,-0.063,-0.060,-0.063,-0.070,-0.085,-0.098,-0.087,-0.075,-0.072,-0.065,-0.065,-0.070,-0.075,-0.085,-0.077,-0.080,-0.070,-0.052,-0.037,-0.052,-0.063,-0.070,-0.080,-0.058,-0.075,-0.060,-0.050,-0.052,-0.060,-0.083,-0.075,-0.092,-0.083,-0.063,-0.045,-0.058,-0.048,-0.068,-0.083,-0.075,-0.072,-0.065,-0.045,-0.045,-0.063,-0.072,-0.080,-0.080,-0.077,-0.060,-0.035,-0.028,0.000,0.018,0.048,0.102,0.185,0.265,0.308,0.302,0.253,0.177,0.085,-0.013,-0.113,-0.220,-0.318,-0.398,-0.460,-0.510,-0.530,-0.522,-0.482,-0.422,-0.373,-0.315,-0.297,-0.282,-0.278,-0.273,-0.248,-0.210,-0.170,-0.135,-0.108,-0.105,-0.100,-0.120,-0.110,-0.115,-0.102,-0.098,-0.090,-0.072,-0.080,-0.098,-0.098,-0.092,-0.090,-0.090,-0.072,-0.065,-0.070,-0.065,-0.075,-0.087,-0.087,-0.083,-0.063,-0.058,-0.048,-0.063,-0.075,-0.070,-0.060,-0.063,-0.058,-0.037,-0.020,-0.015,-0.035,-0.043,-0.028,-0.013,-0.005,0.013,0.028,0.030,0.035,0.025,0.030,0.043,0.072,0.092,0.105,0.138,0.140,0.142,0.153,0.160,0.180,0.210,0.225,0.253,0.263,0.265,0.273,0.275,0.287,0.308,0.328,0.318,0.323,0.300,0.282,0.270,0.255,0.250,0.237,0.225,0.190,0.177,0.153,0.130,0.105,0.092,0.095,0.098,0.077,0.058,0.048,0.037,0.022,0.013,0.010,0.018,0.018,0.013,-0.005,-0.010,-0.022,-0.022,-0.028,-0.010,-0.003,-0.003,-0.015,-0.025,-0.037,-0.037,-0.048,-0.033,-0.022,-0.010,-0.020,-0.037,-0.043,-0.052,-0.048,-0.040,-0.030,-0.025,-0.028,-0.035,-0.035,-0.050,-0.050,-0.045,-0.037,-0.033,-0.022,-0.035,-0.040,-0.055,-0.060,-0.045,-0.050,-0.058,-0.035,-0.040,-0.048,-0.055,-0.055,-0.050,-0.045,-0.025,-0.015,-0.028,-0.035,-0.037,-0.048,-0.045,-0.030,-0.030,-0.025,-0.020,-0.033,-0.048,-0.063,-0.058,-0.068,-0.040,-0.040,-0.033,-0.043,-0.058,-0.072,-0.085,-0.075,-0.068,-0.045,-0.022,-0.020,-0.028,-0.040,-0.048,-0.050,-0.035,-0.028,-0.020,-0.015,-0.025,-0.043,-0.050,-0.045,-0.040,-0.040,-0.030,-0.022,-0.028,-0.035,-0.040,-0.060,-0.043,-0.033,-0.025,-0.010,-0.015,-0.030,-0.040,-0.045,-0.043,-0.037,-0.022,-0.005,-0.013,-0.013,-0.025,-0.040,-0.040,-0.040,-0.018,-0.020,-0.022,-0.015,-0.033,-0.033,-0.025,-0.037,-0.033,-0.003,-0.010,-0.010,-0.010,-0.028,-0.035,-0.030,-0.018,-0.018,0.000,-0.003,-0.013,-0.028,-0.028,-0.030,-0.018,-0.015,-0.005,-0.003,-0.007,-0.013,-0.015,-0.018,-0.025,-0.010,0.000,0.003,0.000,-0.020,-0.025,-0.028,-0.025,-0.015,0.000,0.003,0.005,0.003,-0.010,-0.025,-0.022,-0.020,-0.015,-0.005,0.000,-0.007,-0.018,-0.030,-0.037,-0.028,-0.013,-0.005,-0.015,0.000,-0.013,-0.037,-0.037,-0.022,-0.018,0.000,0.003,0.005,0.003,-0.005,-0.005,-0.022,-0.018,-0.003,0.000,0.007,0.000,-0.007,-0.020,-0.028,-0.020,-0.013,0.000,0.010,0.013,0.000,-0.015,-0.020,-0.015,-0.018,0.005,0.010,0.028,0.007,0.000,-0.007,-0.013,-0.005,0.005,0.015,0.013,0.010,0.005,-0.003,-0.013,-0.015,-0.007,0.007,0.013,0.013,-0.007,-0.015,-0.028,-0.022,-0.007,0.003,0.005,0.015,0.015,0.003,-0.005,-0.020,-0.013,0.000,0.003,0.013,0.000,0.000,-0.010,-0.015,-0.007,-0.003,0.010,0.022,0.013,0.003,-0.005,-0.010,-0.005,-0.005,0.015,0.025,0.043,0.065,0.065,0.098,0.153,0.210,0.290,0.335,0.338,0.275,0.183,0.065,-0.020,-0.110,-0.170,-0.223,-0.255,-0.313,-0.357,-0.395,-0.383,-0.350,-0.302,-0.242,-0.220,-0.218,-0.215,-0.230,-0.223,-0.195,-0.160,-0.105,-0.072,-0.060,-0.060,-0.068,-0.077,-0.077,-0.075,-0.068,-0.052,-0.052,-0.050,-0.050,-0.075,-0.083,-0.077,-0.070,-0.055,-0.035,-0.052,-0.045,-0.060,-0.063,-0.065,-0.050,-0.040,-0.028,-0.030,-0.028,-0.037,-0.045,-0.043,-0.033,-0.040,-0.010,-0.010,0.000,-0.013,-0.018,-0.018,0.000,-0.003,0.028,0.028,0.030,0.033,0.037,0.035,0.055,0.058,0.077,0.090,0.100,0.108,0.115,0.117,0.128,0.147,0.168,0.190,0.218,0.233,0.230,0.233,0.248,0.255,0.275,0.285,0.308,0.325,0.323,0.305,0.292,0.280,0.295,0.287,0.297,0.295,0.260,0.218,0.195,0.177,0.155,0.153,0.150,0.142,0.125,0.113,0.080,0.070,0.055,0.048,0.048,0.058,0.037,0.022,0.018,0.007,0.003,0.000,0.005,0.022,0.022,0.015,0.003,0.003,-0.010,0.000,0.003,0.007,0.013,0.020,0.003,-0.003,-0.013,-0.015,-0.007,0.003,0.000,0.013,0.000,-0.007,-0.018,-0.025,-0.028,-0.013,0.000,0.005,0.005,-0.010,-0.020,-0.010,-0.013,-0.013,0.003,0.010,0.003,0.003,-0.013,-0.033,-0.020,-0.013,-0.005,0.000,0.007,0.000,-0.007,-0.020,-0.020,-0.025,-0.018,0.000,0.003,0.005,-0.010,-0.020,-0.028,-0.020,-0.015,-0.020,-0.003,-0.015,-0.030,-0.048,-0.048,-0.050,-0.052,-0.033,-0.037,-0.022,-0.020,-0.033,-0.033,-0.037,-0.040,-0.015,-0.020,-0.010,-0.015,-0.013,-0.033,-0.030,-0.022,0.000,0.000,0.003,0.003,-0.007,-0.022,-0.025,-0.018,-0.020,-0.015,-0.007,-0.003,-0.018,-0.022,-0.028,-0.030,-0.028,-0.013,0.000,0.000,-0.007,-0.015,-0.015,-0.022,-0.028,-0.007,0.000,0.005,0.000,-0.020,-0.015,-0.020,-0.015,-0.015,-0.005,0.000,0.000,-0.015,-0.025,-0.037,-0.020,-0.025,-0.015,-0.013,-0.003,-0.003,-0.015,-0.020,-0.018,-0.028,-0.010,0.000,0.007,0.010,0.003,-0.013,-0.022,-0.010,-0.010,-0.003,0.013,0.003,0.007,0.000,-0.020,-0.013,-0.025,-0.015,0.007,0.007,0.003,-0.013,-0.015,-0.022,-0.020,-0.007,0.003,0.000,0.015,0.005,-0.010,-0.013,-0.022,-0.013,0.005,0.003,0.013,-0.005,-0.003,-0.018,-0.025,-0.022,-0.010,0.003,0.005,0.000,0.000,-0.013,-0.013,-0.010,-0.005,0.000,0.005,0.000,-0.005,-0.015,-0.010,-0.013,-0.007,0.005,0.015,0.028,0.003,0.007,-0.007,-0.015,-0.018,-0.005,0.005,0.007,0.003,-0.010,-0.020,-0.020,-0.022,-0.005,0.013,0.015,-0.005,-0.003,-0.010,-0.013,-0.015,-0.005,0.000,0.015,0.018,0.000,-0.007,-0.010,-0.013,-0.015,-0.003,0.010,0.018,0.005,-0.005,-0.013,-0.015,-0.007,-0.007,0.007,0.022,0.018,0.013,-0.007,-0.005,-0.010,0.003,0.007,0.015,0.015,0.018,0.007,-0.010,-0.013,0.000,0.007,0.015,0.028,0.022,0.015,-0.003,-0.015,-0.010,0.000,0.028,0.048,0.083,0.138,0.212,0.300,0.383,0.420,0.398,0.335,0.245,0.138,0.020,-0.095,-0.190,-0.263,-0.310,-0.313,-0.300,-0.263,-0.237,-0.225,-0.223,-0.210,-0.205,-0.188,-0.155,-0.142,-0.117,-0.108,-0.092,-0.075,-0.072,-0.058,-0.050,-0.043,-0.052,-0.050,-0.065,-0.060,-0.050,-0.040,-0.030,-0.037,-0.030,-0.040,-0.055,-0.050,-0.045,-0.048,-0.040,-0.020,-0.028,-0.037,-0.048,-0.037,-0.035,-0.020,-0.010,-0.003,0.000,0.000,-0.022,-0.015,-0.025,-0.005,0.000,0.005,0.013,0.035,0.028,0.020,0.028,0.030,0.035,0.063,0.072,0.085,0.080,0.087,0.083,0.102,0.120,0.145,0.170,0.180,0.177,0.180,0.180,0.198,0.205,0.233,0.265,0.273,0.282,0.282,0.285,0.290,0.297,0.308,0.330,0.325,0.333,0.325,0.308,0.275,0.275,0.255,0.250,0.245,0.235,0.215,0.198,0.177,0.155,0.145,0.128,0.125,0.115,0.098,0.090,0.058,0.052,0.043,0.037,0.050,0.055,0.048,0.030,0.010,0.000,0.005,0.015,0.013,0.025,0.025,0.013,0.005,-0.005,0.000,-0.013,0.005,0.015,0.025,0.005,0.005,-0.015,-0.015,-0.022,-0.013,0.000,0.005,0.000,-0.010,-0.015,-0.035,-0.033,-0.030,-0.007,0.000,-0.007,-0.007,-0.013,-0.022,-0.018,-0.020,-0.007,0.000,-0.003,0.000,-0.015,-0.028,-0.030,-0.028,-0.025,-0.020,-0.007,-0.005,-0.005,-0.010,-0.033,-0.030,-0.022,-0.015,-0.010,-0.005,-0.018,-0.018,-0.022,-0.025,-0.025,-0.013,0.000,-0.007,-0.003,-0.030,-0.033,-0.048,-0.052,-0.040,-0.035,-0.033,-0.035,-0.035,-0.045,-0.040,-0.037,-0.025,-0.015,-0.015,-0.003,-0.022,-0.028,-0.025,-0.037,-0.020,-0.020,-0.003,-0.003,-0.007,-0.010,-0.040,-0.033,-0.030,-0.022,-0.010,-0.005,-0.010,-0.022,-0.035,-0.037,-0.030,-0.025,-0.015,-0.003,-0.018,-0.020,-0.025,-0.037,-0.033,-0.037,-0.025,-0.005,0.003,-0.007,-0.025,-0.025,-0.035,-0.025,-0.015,-0.010,0.003,-0.010,-0.022,-0.020,-0.033,-0.037,-0.025,-0.018,0.005,-0.010,-0.022,-0.025,-0.033,-0.048,-0.037,-0.020,-0.013,-0.003,-0.007,-0.015,-0.025,-0.025,-0.037,-0.020,-0.010,-0.003,0.000,-0.003,-0.018,-0.020,-0.020,-0.018,-0.003,0.003,-0.003,-0.005,-0.022,-0.020,-0.022,-0.022,-0.015,0.003,0.007,0.010,0.000,-0.020,-0.018,-0.022,-0.015,0.000,0.005,-0.003,-0.007,-0.028,-0.028,-0.035,-0.025,-0.010,0.000,0.000,-0.003,-0.018,-0.033,-0.045,-0.020,-0.010,0.000,0.000,-0.005,-0.007,-0.022,-0.018,-0.025,-0.013,-0.003,0.005,0.007,-0.010,-0.015,-0.022,-0.033,-0.025,-0.007,0.000,0.005,-0.003,-0.013,-0.022,-0.028,-0.015,-0.010,-0.005,0.000,0.000,-0.007,-0.020,-0.022,-0.020,-0.007,0.005,0.007,-0.005,-0.005,-0.018,-0.028,-0.025,-0.022,0.000,-0.005,-0.003,0.000,-0.007,-0.007,-0.018,-0.018,-0.018,0.000,-0.003,0.000,-0.003,-0.007,-0.015,-0.013,-0.005,0.013,0.015,0.018,0.007,-0.003,-0.010,-0.013,-0.007,0.000,0.013,0.015,0.005,0.000,-0.030,-0.020,-0.015,-0.018,0.013,0.018,0.025,0.033,0.060,0.087,0.133,0.205,0.285,0.345,0.383,0.362,0.313,0.237,0.142,0.043,-0.048,-0.115,-0.188,-0.255,-0.310,-0.355,-0.388,-0.405,-0.388,-0.350,-0.297,-0.253,-0.225,-0.218,-0.207,-0.203,-0.183,-0.140,-0.115,-0.085,-0.070,-0.072,-0.083,-0.072,-0.065,-0.063,-0.058,-0.040,-0.055,-0.060,-0.070,-0.070,-0.065,-0.070,-0.055,-0.045,-0.052,-0.055,-0.072,-0.065,-0.072,-0.065,-0.040,-0.040,-0.035,-0.043,-0.052,-0.055,-0.052,-0.045,-0.028,-0.025,-0.018,-0.013,-0.022,-0.018,-0.025,-0.013,0.000,0.013,0.022,0.018,0.022,0.007,0.018,0.040,0.045,0.075,0.077,0.092,0.087,0.092,0.100,0.105,0.125,0.160,0.180,0.198,0.210,0.223,0.225,0.235,0.250,0.270,0.300,0.305,0.305,0.313,0.305,0.320,0.305,0.313,0.318,0.330,0.308,0.300,0.268,0.245,0.235,0.215,0.218,0.203,0.200,0.165,0.140,0.117,0.108,0.092,0.095,0.100,0.085,0.068,0.052,0.025,0.028,0.018,0.010,0.028,0.037,0.018,0.010,0.003,-0.003,-0.010,-0.003,0.007,0.020,0.015,0.015,0.015,-0.003,-0.005,0.000,0.003,0.015,0.013,0.015,0.000,-0.015,-0.013,-0.010,-0.003,0.003,0.007,0.010,-0.005,-0.015,-0.022,-0.015,-0.007,-0.013,0.007,0.007,0.010,-0.003,-0.013,-0.020,-0.022,-0.013,-0.005,-0.007,0.000,-0.005,-0.020,-0.018,-0.020,-0.010,0.003,0.005,-0.013,0.000,-0.015,-0.030,-0.020,-0.015,-0.018,-0.005,-0.018,-0.025,-0.033,-0.040,-0.048,-0.043,-0.040,-0.030,-0.037,-0.030,-0.028,-0.033,-0.033,-0.035,-0.015,-0.025,-0.003,-0.010,-0.005,-0.020,-0.025,-0.033,-0.025,-0.013,-0.005,-0.007,-0.018,-0.020,-0.025,-0.025,-0.018,-0.018,-0.005,0.000,-0.003,-0.015,-0.025,-0.033,-0.025,-0.025,0.003,-0.007,0.000,-0.005,-0.018,-0.030,-0.018,-0.018,-0.003,0.010,0.003,-0.005,-0.022,-0.020,-0.013,-0.035,-0.015,0.000,0.007,0.003,-0.013,-0.010,-0.015,-0.018,-0.010,-0.003,0.003,0.000,-0.010,-0.015,-0.033,-0.020,-0.025,-0.005,0.000,0.013,0.000,-0.010,-0.020,-0.033,-0.020,-0.013,0.007,0.007,0.015,-0.007,-0.013,-0.013,-0.015,-0.007,0.000,0.015,0.005,0.000,-0.003,-0.013,-0.018,-0.005,-0.005,0.010,0.013,0.003,-0.010,-0.018,-0.010,-0.010,-0.007,0.000,0.015,0.015,0.003,-0.005,-0.020,-0.007,-0.010,0.013,0.005,0.018,0.007,-0.005,-0.022,-0.010,-0.013,0.003,0.005,0.018,0.007,-0.003,-0.015,-0.007,-0.013,-0.005,0.007,0.005,0.003,-0.003,-0.005,-0.003,-0.015,0.003,0.018,0.013,0.005,0.005,-0.007,-0.013,-0.005,-0.007,0.003,0.013,0.018,0.010,0.003,-0.010,-0.010,-0.013,0.000,0.015,0.015,0.015,-0.003,0.000,-0.007,-0.007,-0.007,0.007,0.015,0.010,0.003,0.000,-0.010,-0.022,-0.015,0.000,0.025,0.018,0.010,0.003,-0.007,-0.003,-0.003,0.010,0.013,0.020,0.018,0.003,-0.003,-0.013,-0.003,0.003,0.022,0.022,0.020,0.005,-0.005,-0.003,0.000,0.005,0.033,0.048,0.085,0.110,0.140,0.220,0.297,0.370,0.388,0.355,0.270,0.165,0.033,-0.092,-0.180,-0.270,-0.338,-0.385,-0.425,-0.465,-0.458,-0.438,-0.395,-0.338,-0.295,-0.248,-0.215,-0.203,-0.212,-0.225,-0.215,-0.185,-0.125,-0.083,-0.037,-0.028,-0.033,-0.030,-0.052,-0.055,-0.055,-0.037,-0.028,-0.010,-0.007,-0.020,-0.028,-0.018,-0.030};

        ProcessingDigitized RRDetector = new ProcessingDigitized(ECGdigitized);
        int HeartRate = RRDetector.GetHeartRate();
        String strHeartRate = Integer.toString(HeartRate);
        mMainForm.append(new StringItem(null, "Calculated Heart Rate: " + strHeartRate + " beats per minute." ));
        
    
    }    
    catch(Exception x)
    {
        mMainForm.append(new StringItem(null,"Error entering element into data matrix. " + x.toString()));   
    }
    
}
  
  public void pauseApp() {}
  
  public void destroyApp(boolean unconditional) {}
  
  public void commandAction(Command c, Displayable s) {
    notifyDestroyed();
  }
  
  
}
