%R-R Peak Detection Test
%Author: Sandra Escandor, 2010
%Note: This is just a rough outline of what needs to be done for RR peak
%detection. We'll need to make the code better (i.e put the positive slope
%and negative slope detectors in their own functions). 

clc;
clear;
fid = fopen('PhysioNetData_ECG.txt');
[A length] = fscanf(fid, '%f'); 
%sampling period: 0.001
samplePeriod = 0.004; %in seconds!
cntPosThresh = 2; %the number of positive slope thresholds that need to be counted in order to find R peak
cntNegThresh = 2;
allowableExamineRange = 15; %the range of number of samples that the negative slope needs to be found
%plot(A,'--rs','LineWidth',2,...
 %               'MarkerEdgeColor','k',...
 %               'MarkerFaceColor','g',...
 %               'MarkerSize',10);

plot(A), xlabel('Data sample number'), ylabel('mV'); 
 
%Do the first derivative approach:

%Find the average positive slope
m = 0;
n = 0; %The number of positive slopes
examinedIndex = 2*m;
AverageSlope = 0;

while (examinedIndex+2) < length
    m = m + 1;
    
    examinedIndex = 2*m;
    slope = (A(examinedIndex+1)-A(examinedIndex-1))/samplePeriod;
    
    if slope>0        
        n = n+1;
        AverageSlope = AverageSlope + slope;
    end
end
AverageSlope = AverageSlope/n

positiveSlopeThresh = AverageSlope + AverageSlope*2.5 %We want a variable positive slope threshold.

%Find the average negative slope
m = 0;
n = 0; %The number of positive slopes
examinedIndex = 2*m;
AverageSlope = 0;
while examinedIndex+2 < length
    m = m + 1;
    
    examinedIndex = 2*m;
    slope = (A(examinedIndex+1)-A(examinedIndex-1))/samplePeriod;
    
    if slope<0        
        n = n+1;
        AverageSlope = AverageSlope + slope;
    end
end
AverageSlope = AverageSlope/n

negativeSlopeThresh = AverageSlope + AverageSlope*2.5 %We want a variable negative slope threshold

%****************Start of R peak***********************
%if there are 3 consecutive points that have a positive slope 
%that is greater than the positive slope threshold, then mark the last 
%examined point as the start of the R peak.
posSlopeCnt = 0;

%examine every even indexed data x(n)
%then calculate [x(n+1)-x(n-1)]/samplePeriod
i = 0;
examinedIndex = 2 * i;

while posSlopeCnt < cntPosThresh && examinedIndex+2 < length
    
    i = i + 1;
    
    examinedIndex = 2*i;
    slope = (A(examinedIndex+1)-A(examinedIndex-1))/samplePeriod;
    if slope >= positiveSlopeThresh
        
        if posSlopeCnt > 0
            posSlopeCnt = posSlopeCnt + 1;
        else
            
            if posSlopeCnt == 0
                posSlopeCnt = 1;
            else                
                posSlopeCnt = 0; %reset the slope count so we can find a consecutive set of slopes that are at least above the threshold
            end
            
        end
    else
        posSlopeCnt = 0;
    end
       
end

FirstRPeakStartLoc = examinedIndex

%************************* END OF R PEAK
negSlopeCnt = 0;

while (negSlopeCnt < cntNegThresh) && (examinedIndex+2 < length) && (examinedIndex-FirstRPeakStartLoc < allowableExamineRange)
    i = i + 1;
    examinedIndex = 2*i;
    slope = (A(examinedIndex+1)-A(examinedIndex-1))/samplePeriod;
    if slope <= negativeSlopeThresh
        
        if negSlopeCnt > 0
            negSlopeCnt = negSlopeCnt + 1;
        else
            
            if negSlopeCnt == 0
                negSlopeCnt = 1;
            else                
                negSlopeCnt = 0; %reset the slope count so we can find a consecutive set of slopes that are at least above the threshold
            end
            
        end
    else
        negSlopeCnt = 0;
    end
    
end

FirstRPeakEndLoc = examinedIndex


%****************Start of R peak***********************
%if there are 3 consecutive points that have a positive slope 
%that is greater than the positive slope threshold, then mark the last 
%examined point as the start of the R peak.
posSlopeCnt = 0;

%examine every even indexed data x(n)
%then calculate [x(n+1)-x(n-1)]/samplePeriod

examinedIndex = 2 * i;
consecutive = false;
while posSlopeCnt < cntPosThresh && examinedIndex+2 < length
    
    i = i + 1;
    
    examinedIndex = 2*i;
    slope = (A(examinedIndex+1)-A(examinedIndex-1))/samplePeriod;
    if slope >= positiveSlopeThresh
        
        if posSlopeCnt > 0
            posSlopeCnt = posSlopeCnt + 1;
        else
            
            if posSlopeCnt == 0
                posSlopeCnt = 1;
            else                
                posSlopeCnt = 0; %reset the slope count so we can find a consecutive set of slopes that are at least above the threshold
            end
            
        end
    else
        posSlopeCnt = 0;
    end
       
end

SecondRPeakStartLoc = examinedIndex


%************************* END OF R PEAK
negSlopeCnt = 0;

while (negSlopeCnt < cntNegThresh) && (examinedIndex+2 < length) && (examinedIndex-SecondRPeakStartLoc < allowableExamineRange)
    i = i + 1;
    examinedIndex = 2*i;
    slope = (A(examinedIndex+1)-A(examinedIndex-1))/samplePeriod;
    if slope <= negativeSlopeThresh
        
        if negSlopeCnt > 0
            negSlopeCnt = negSlopeCnt + 1;
        else
            
            if negSlopeCnt == 0
                negSlopeCnt = 1;
            else                
                negSlopeCnt = 0; %reset the slope count so we can find a consecutive set of slopes that are at least above the threshold
            end
            
        end
    else
        negSlopeCnt = 0;
    end
    
end

SecondRPeakEndLoc = examinedIndex

[maxFirstPeak maxLoc] = max(A(FirstRPeakStartLoc:FirstRPeakEndLoc))
FirstRIndex = FirstRPeakStartLoc + maxLoc

[maxSecondPeak maxLoc] = max(A(SecondRPeakStartLoc:SecondRPeakEndLoc))
SecondRIndex = SecondRPeakStartLoc + maxLoc

HeartRate = int8(60/((SecondRIndex - FirstRIndex)*samplePeriod))

%Generate java code for the sample data:

% open the file with write permission
fid = fopen('ECG.txt', 'w');
[rows cols] = size(A);

%generate java code for the sample data
fprintf(fid, 'double[] ECGdigitized = {');
for i = 1:rows
    
    if(i ~= rows)
        fprintf(fid, '%3.3f,', A(i));
    else
        fprintf(fid, '%3.3f', A(i));
    end
end
fprintf(fid, '};\n');

fclose(fid);

% view the contents of the file
type ECG.txt
